/** IE6 is a hunk of crap!!! due to limitations in the CSS capabilities of IE, these hacks are required **/

/** horid IE render order bug - http://www.positioniseverything.net/explorer/percentages.html */

span.pathway {
	position: relative;
	height: 1%;
}

/* hacks for RokSlide */

#topmodules,
#bottommodules {
	zoom: 1;
}